@@ -51,10 +51,14 @@ class Country(DeactivableMixin, ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
+        if clause[1].startswith('!') or clause[1].startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
         code_value = clause[2]
         if clause[1].endswith('like'):
             code_value = lstrip_wildcard(clause[2])
-        return ['OR',
+        return [bool_op,
             ('name',) + tuple(clause[1:]),
             ('code', clause[1], code_value) + tuple(clause[3:]),
             ('code3', clause[1], code_value) + tuple(clause[3:]),
@@ -226,9 +230,16 @@ class Subdivision(DeactivableMixin, ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return ['OR',
+        if clause[1].startswith('!') or clause[1].startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        code_value = clause[2]
+        if clause[1].endswith('like'):
+            code_value = lstrip_wildcard(clause[2])
+        return [bool_op,
             ('name',) + tuple(clause[1:]),
-            ('code',) + tuple(clause[1:]),
+            ('code', clause[1], code_value) + tuple(clause[3:]),
             ]
 
     @classmethod
@@ -293,7 +304,10 @@ class PostalCode(ModelSQL, ModelView):
             bool_op = 'AND'
         else:
             bool_op = 'OR'
+        code_value = clause[2]
+        if clause[1].endswith('like'):
+            code_value = lstrip_wildcard(clause[2])
         return [bool_op,
-            ('postal_code',) + tuple(clause[1:]),
+            ('postal_code', clause[1], code_value) + tuple(clause[3:]),
             ('city',) + tuple(clause[1:]),
             ]
